pub struct SnapshotConfig {
pub dir: PathBuf,
pub checkpoint_every_commits: Option<u64>,
pub keep_old: usize,
pub codec: SnapshotOptions,
}Fields
dir: PathBufcheckpoint_every_commits: Option<u64>When set, create a managed checkpoint after this many committed WAL
transactions. None keeps checkpointing manual via sync() /
checkpoint_managed().
keep_old: usizeNumber of older checkpoint files to retain in addition to CURRENT.
codec: SnapshotOptionsColumnar snapshot codec options. Defaults to fast gzip compression and no encryption.
Implementations