pub struct WalStatus {
pub durable_lsn: u64,
pub next_lsn: u64,
pub active_segment_id: u64,
pub oldest_segment_id: u64,
pub bg_failure: Option<String>,
}Expand description
Snapshot of WAL state returned by WalAdmin::wal_status.
bg_failure is the latched fsync error from the background flusher
(only meaningful under SyncMode::Group). When Some, the WAL is
poisoned and every subsequent commit will fail loudly until the
operator restarts from the last consistent snapshot + WAL.
Fields
durable_lsn: u64next_lsn: u64active_segment_id: u64oldest_segment_id: u64bg_failure: Option<String>Trait Implementations