snapshot_credentials_from_json

Function snapshot_credentials_from_json 

pub fn snapshot_credentials_from_json(
    value: Option<Value>,
) -> Result<Option<SnapshotCredentials>>
Build snapshot load credentials from the JSON shape used by the language bindings. The credential object may be supplied directly, or under credentials / encryption so the same options object can be reused for save and load.